@@ -362,11 +362,15 @@ def main(args=None):
     ###############################
     #   Setup amount of GPU memory used
     ###############################
+    config_proto_args = {}
+    if args.num_cpu != -1:
+        config_proto_args["intra_op_parallelism_threads"] = args.num_cpu
+        config_proto_args["inter_op_parallelism_threads"] = args.num_cpu
     if args.gpu_fraction < 1.0 and args.gpu_fraction > 0.0:
         import tensorflow as tf
         from keras.backend.tensorflow_backend import set_session
 
-        config = tf.compat.v1.ConfigProto()
+        config = tf.compat.v1.ConfigProto(**config_proto_args)
 
         config.gpu_options.allow_growth = True
         config.gpu_options.per_process_gpu_memory_fraction = args.gpu_fraction
@@ -376,7 +380,7 @@ def main(args=None):
         import tensorflow as tf
         from keras.backend.tensorflow_backend import set_session
 
-        config = tf.compat.v1.ConfigProto()
+        config = tf.compat.v1.ConfigProto(**config_proto_args)
         config.gpu_options.allow_growth = True
 
         set_session(tf.compat.v1.Session(config=config))
